<?php

/**
 * @file
 * File Chooser Field page callbacks.
 */

/**
 * Redirect URL callback.
 */
function file_chooser_field_redirect_callback($phpClassName) {
  module_load_include('inc', 'file_chooser_field');

  if (!empty($phpClassName)) {
    $redirectCallback = file_chooser_field_plugin_method($phpClassName, 'redirectCallback');
    if ($redirectCallback) {
      return $redirectCallback;
    }
  }

  return ' ';

}

/**
 * File Chooser Field settings form.
 */
function file_chooser_field_admin_settings() {
  module_load_include('inc', 'file_chooser_field');

  $enabled_plugins = array();

  $form['settings'] = array(
    '#type' => 'vertical_tabs',
    '#attached' => array(
      'js' => array(
        drupal_get_path('module', 'file_chooser_field') . '/js/file_chooser_field.form.js'
      ),
    ),
  );

  $plugins = file_chooser_field_load_plugins();
  foreach ($plugins as $name => $plugin) {

    // List of enabled plugins. This goes to Drupal.settings.
    $enabled_plugins[] = $name;

    $form['settings'][$name] = array(
      '#type' => 'fieldset',
      '#title' => $plugin['name'],
    );

    $form['settings'][$name]['file_chooser_field_' . $name . '_enabled'] = array(
      '#type' => 'checkbox',
      '#title' => t('Enable plugin'),
      '#default_value' => variable_get('file_chooser_field_' . $name . '_enabled', FALSE),
      '#description' => t("Disabled plugins are not visible in <em>File</em> and <em>Image</em> fields."),
    );

    $configForm = file_chooser_field_plugin_method($plugin['phpClassName'], 'configForm');
    if (is_array($configForm)) {
      $form['settings'][$name] += $configForm;
    }

    $redirectCallback = file_chooser_field_plugin_method($plugin['phpClassName'], 'redirectCallback');
    if ($redirectCallback) {
      $form['settings'][$name]['file_chooser_field_' . $name . '_redirect_url'] = array(
        '#markup' => '<em>' . url('redirectCallback/' . $plugin['phpClassName'], array('absolute' => TRUE)) . '</em>',
        '#prefix' => '<div><strong>' . t('Redirect URL') . '</strong></div>',
        '#suffix' => '<div class="description">' . t('This is the URL you will need for the redirect URL/OAuth authentication') . '</div>',
      );
    }

  }

  if (!empty($enabled_plugins)) {
    drupal_add_js(
      array(
        'file_chooser_field' => array(
          'enabled_plugins' => $enabled_plugins,
        )
      ),
      'setting'
    );
  }

  return system_settings_form($form);
}
